==> mingw-w64-starpu-1.4.0-2.src.tar.zst: starpu-1.4.0/doc/doxygen_web_performances/html_web_performances/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Performances", "index.html", [
    [ "Organization", "index.html#Organization", null ],
    [ "Benchmarking StarPU", "BenchmarkingStarPU.html", [
      [ "Task Size Overhead", "BenchmarkingStarPU.html#TaskSizeOverhead", null ],
      [ "Data Transfer Latency", "BenchmarkingStarPU.html#DataTransferLatency", null ],
      [ "Matrix-Matrix Multiplication", "BenchmarkingStarPU.html#MatrixMatrixMultiplication", null ],
      [ "Cholesky Factorization", "BenchmarkingStarPU.html#CholeskyFactorization", null ],
      [ "LU Factorization", "BenchmarkingStarPU.html#LUFactorization", null ],
      [ "Simulated Benchmarks", "BenchmarkingStarPU.html#SimulatedBenchmarks", null ]
    ] ],
    [ "Online Performance Tools", "OnlinePerformanceTools.html", [
      [ "On-line Performance Feedback", "OnlinePerformanceTools.html#On-linePerformanceFeedback", [
        [ "Enabling On-line Performance Monitoring", "OnlinePerformanceTools.html#EnablingOn-linePerformanceMonitoring", null ],
        [ "Per-task Feedback", "OnlinePerformanceTools.html#Per-taskFeedback", null ],
        [ "Per-codelet Feedback", "OnlinePerformanceTools.html#Per-codeletFeedback", null ],
        [ "Per-worker Feedback", "OnlinePerformanceTools.html#Per-workerFeedback", null ],
        [ "Bus-related Feedback", "OnlinePerformanceTools.html#Bus-relatedFeedback", null ],
        [ "MPI-related Feedback", "OnlinePerformanceTools.html#MPI-relatedFeedback", null ]
      ] ],
      [ "Task And Worker Profiling", "OnlinePerformanceTools.html#TaskAndWorkerProfiling", null ],
      [ "Performance Model Example", "OnlinePerformanceTools.html#PerformanceModelExample", null ],
      [ "Performance Monitoring Counters", "OnlinePerformanceTools.html#PerformanceMonitoringCounters", [
        [ "Objectives", "OnlinePerformanceTools.html#PerfMonCountObjectives", null ],
        [ "Entities", "OnlinePerformanceTools.html#PerfMonCountEntities", [
          [ "Performance Counter", "OnlinePerformanceTools.html#PerfMonCountCounter", null ],
          [ "Performance Counter Type", "OnlinePerformanceTools.html#PerfMonCountCounterType", null ],
          [ "Performance Counter Scope", "OnlinePerformanceTools.html#PerfMonCountCounterScope", null ],
          [ "Performance Counter Set", "OnlinePerformanceTools.html#PerfMonCountCounterSet", null ],
          [ "Performance Counter Sample", "OnlinePerformanceTools.html#PerfMonCountCounterSample", null ],
          [ "Performance Counter Listener", "OnlinePerformanceTools.html#PerfMonCountCounterListener", null ],
          [ "Application Programming Interface", "OnlinePerformanceTools.html#PerfMonCountCounterAPI", null ],
          [ "Scope Related Routines", "OnlinePerformanceTools.html#PerfMonCountCounterScopeRoutines", null ],
          [ "Type Related Routines", "OnlinePerformanceTools.html#PerfMonCountCounterTypeRoutines", null ],
          [ "Counter Related Routines", "OnlinePerformanceTools.html#PerfMonCountCounterCounterRoutines", null ],
          [ "Counter Set Related Routines", "OnlinePerformanceTools.html#PerfMonCountCounterCounterSetRoutines", null ],
          [ "Listener Related Routines", "OnlinePerformanceTools.html#PerfMonCountCounterListenerRoutines", null ],
          [ "Sample Related Routines", "OnlinePerformanceTools.html#PerfMonCountCounterSampleRoutines", null ]
        ] ],
        [ "Implementation Details", "OnlinePerformanceTools.html#PerfMonCountCounterImplementation", [
          [ "Performance Counter Registration", "OnlinePerformanceTools.html#PerfMonCountCounterImplRegistration", null ],
          [ "Performance Sample Updaters", "OnlinePerformanceTools.html#PerfMonCountCounterImplUpdaters", null ],
          [ "Counter operations", "OnlinePerformanceTools.html#PerfMonCountCounterImplOperations", null ],
          [ "Runtime checks", "OnlinePerformanceTools.html#PerfMonCountCounterImplRuntime", null ]
        ] ],
        [ "Exported Counters", "OnlinePerformanceTools.html#PerfMonCountCounterExported", [
          [ "Global Scope", "OnlinePerformanceTools.html#PerfMonCountCounterExportedGlobal", null ],
          [ "Per-worker Scope", "OnlinePerformanceTools.html#PerfMonCountCounterExportedPerWorker", null ],
          [ "Per-Codelet Scope", "OnlinePerformanceTools.html#PerfMonCountCounterExportedPerCodelet", null ]
        ] ],
        [ "Sequence of operations", "OnlinePerformanceTools.html#PerfMonCountCounterSequence", null ]
      ] ],
      [ "Performance Steering Knobs", "OnlinePerformanceTools.html#PerfKnobs", [
        [ "Objectives", "OnlinePerformanceTools.html#PerfKnobsObjectives", null ],
        [ "Entities", "OnlinePerformanceTools.html#PerfKnobsEntities", [
          [ "Performance Steering Knob", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnob", null ],
          [ "Knob Type", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnobType", null ],
          [ "Knob Scope", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnobScope", null ],
          [ "Knob Group", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnobGroup", null ]
        ] ],
        [ "Application Programming Interface", "OnlinePerformanceTools.html#PerfKnobsAPI", [
          [ "Scope Related Routines", "OnlinePerformanceTools.html#PerfKnobsAPIScope", null ],
          [ "Type Related Routines", "OnlinePerformanceTools.html#PerfKnobsAPIType", null ],
          [ "Performance Steering Knob Related Routines", "OnlinePerformanceTools.html#PerfKnobsAPISteer", null ]
        ] ],
        [ "Implementation Details", "OnlinePerformanceTools.html#PerfKnobsImpl", null ],
        [ "Exported Steering Knobs", "OnlinePerformanceTools.html#PerfKnobsExported", [
          [ "Global Scope", "OnlinePerformanceTools.html#PerfKnobsExportedGlobal", null ],
          [ "Per-worker Scope", "OnlinePerformanceTools.html#PerfKnobsExportedPerWorker", null ],
          [ "Per-Scheduler Scope", "OnlinePerformanceTools.html#PerfKnobsExportedPerScheduler", null ]
        ] ],
        [ "Sequence of operations", "OnlinePerformanceTools.html#PerfKnobsSequence", null ]
      ] ]
    ] ],
    [ "Offline Performance Tools", "OfflinePerformanceTools.html", [
      [ "Off-line Performance Feedback", "OfflinePerformanceTools.html#Off-linePerformanceFeedback", [
        [ "Generating Traces With FxT", "OfflinePerformanceTools.html#GeneratingTracesWithFxT", [
          [ "Creating a Gantt Diagram", "OfflinePerformanceTools.html#CreatingAGanttDiagram", null ],
          [ "Creating a DAG With Graphviz", "OfflinePerformanceTools.html#CreatingADAGWithGraphviz", null ],
          [ "Getting Task Details", "OfflinePerformanceTools.html#TraceTaskDetails", null ],
          [ "Getting Scheduling Task Details", "OfflinePerformanceTools.html#TraceSchedTaskDetails", null ],
          [ "Monitoring Activity", "OfflinePerformanceTools.html#MonitoringActivity", null ],
          [ "Getting Modular Schedular Animation", "OfflinePerformanceTools.html#Animation", null ],
          [ "Analyzing Time Between MPI Data Transfer and Use by Tasks", "OfflinePerformanceTools.html#TimeBetweenSendRecvDataUse", null ],
          [ "Number of events in trace files", "OfflinePerformanceTools.html#NumberEvents", null ]
        ] ],
        [ "Limiting The Scope Of The Trace", "OfflinePerformanceTools.html#LimitingScopeTrace", null ]
      ] ],
      [ "Performance Of Codelets", "OfflinePerformanceTools.html#PerformanceOfCodelets", null ],
      [ "Energy Of Codelets", "OfflinePerformanceTools.html#EnergyOfCodelets", null ],
      [ "Data trace and tasks length", "OfflinePerformanceTools.html#DataTrace", null ],
      [ "Trace Statistics", "OfflinePerformanceTools.html#TraceStatistics", null ],
      [ "PAPI counters", "OfflinePerformanceTools.html#PapiCounters", null ],
      [ "Theoretical Lower Bound On Execution Time", "OfflinePerformanceTools.html#TheoreticalLowerBoundOnExecutionTime", null ],
      [ "Trace visualization with StarVZ", "OfflinePerformanceTools.html#starvz", null ],
      [ "StarPU Eclipse Plugin", "OfflinePerformanceTools.html#EclipsePlugin", [
        [ "Eclipse Installation", "OfflinePerformanceTools.html#EclipseInstallation", null ],
        [ "StarPU Eclipse Plugin Compilation and Installation", "OfflinePerformanceTools.html#PluginInstallation", null ],
        [ "StarPU Eclipse Plugin Instruction", "OfflinePerformanceTools.html#PluginInstruction", null ]
      ] ],
      [ "Memory Feedback", "OfflinePerformanceTools.html#MemoryFeedback", null ],
      [ "Data Statistics", "OfflinePerformanceTools.html#DataStatistics", null ],
      [ "Tracing MPI applications", "OfflinePerformanceTools.html#TraceMpi", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"",
"globals_func.html",
"group__API__Codelet__And__Tasks.html#ga3f27bbe96afa84eca01264746837d692",
"group__API__Data__Interfaces.html#a975914df540caa34fd0f469d242e3a40",
"group__API__Data__Interfaces.html#ga75d457d6e5181fff12d031d2a2c6db28",
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca40a80154bc81a5eb4eea06771010bba3",
"group__API__Data__Partition.html#ga47a12b7cc94a8bff0654761c36b8105d",
"group__API__FxT__Support.html#ga2e55ad671e94b6161755717b1c8b44c1",
"group__API__Insert__Task.html#ga5f1ac909f44c54090ea1106c37a544e5",
"group__API__MPI__Support.html#ga0a464b972068bac652622d6a1ed0a996",
"group__API__Miscellaneous__Helpers.html#ga4c4f93f8ed79333f5801058af4267d84",
"group__API__Modularized__Scheduler.html#gaf2c80ef8ccc38d6d2bb69ba3c5299c25",
"group__API__OpenMP__Runtime__Support.html#gabbd8c55707eb2173324c7dcfe04832f3",
"group__API__Perf__Monitoring.html#ga76a5942c06f505f23282f6b423f4e8f4",
"group__API__Performance__Model.html#ga8dd71674604b4449bf3cabd5e85012c1",
"group__API__SC__Hypervisor.html#aea7e98763fa2b2f5553cc73bf29705f7",
"group__API__Scheduler__Toolbox.html#gaaf3e157f80bacdafe5d73e85e26ce3ac",
"group__API__Scheduling__Policy.html#gadf8e42d41b76117293db5651b0912c78",
"group__API__Threads.html#gac93d8e7fcb44d354421a77b1c0bc9569",
"group__API__Workers__Properties.html#gac043c52077692456604a2f2f161b86ba",
"interfacefstarpu__mod_1_1fstarpu__data__handle__to__pointer.html#a5259fce6ed5628ab3c35ab3558165b50",
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__set__max__priority.html#a5a54b97cfe7ed8d8c2979cfeddad0bcd",
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__isend__detached__unlock__tag__prio.html#aa0007a2389dd3fae996e774f4d268701",
"sc__hypervisor__policy_8h_source.html",
"starpu__thread_8h.html#a88511b963d9c124e6e33a30fccb80501"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mingw-w64-starpu-1.4.2-1.src.tar.zst: starpu-1.4.2/doc/doxygen_web_performances/html_web_performances/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Performances", "index.html", [
    [ "Benchmarking StarPU", "BenchmarkingStarPU.html", [
      [ "Task Size Overhead", "BenchmarkingStarPU.html#TaskSizeOverhead", null ],
      [ "Data Transfer Latency", "BenchmarkingStarPU.html#DataTransferLatency", null ],
      [ "Matrix-Matrix Multiplication", "BenchmarkingStarPU.html#MatrixMatrixMultiplication", null ],
      [ "Cholesky Factorization", "BenchmarkingStarPU.html#CholeskyFactorization", null ],
      [ "LU Factorization", "BenchmarkingStarPU.html#LUFactorization", null ],
      [ "Simulated Benchmarks", "BenchmarkingStarPU.html#SimulatedBenchmarks", null ]
    ] ],
    [ "Online Performance Tools", "OnlinePerformanceTools.html", [
      [ "On-line Performance Feedback", "OnlinePerformanceTools.html#On-linePerformanceFeedback", [
        [ "Enabling On-line Performance Monitoring", "OnlinePerformanceTools.html#EnablingOn-linePerformanceMonitoring", null ],
        [ "Per-task Feedback", "OnlinePerformanceTools.html#Per-taskFeedback", null ],
        [ "Per-codelet Feedback", "OnlinePerformanceTools.html#Per-codeletFeedback", null ],
        [ "Per-worker Feedback", "OnlinePerformanceTools.html#Per-workerFeedback", null ],
        [ "Bus-related Feedback", "OnlinePerformanceTools.html#Bus-relatedFeedback", null ],
        [ "MPI-related Feedback", "OnlinePerformanceTools.html#MPI-relatedFeedback", null ]
      ] ],
      [ "Task And Worker Profiling", "OnlinePerformanceTools.html#TaskAndWorkerProfiling", null ],
      [ "Performance Model Example", "OnlinePerformanceTools.html#PerformanceModelExample", null ],
      [ "Performance Monitoring Counters", "OnlinePerformanceTools.html#PerformanceMonitoringCounters", [
        [ "Objectives", "OnlinePerformanceTools.html#PerfMonCountObjectives", null ],
        [ "Entities", "OnlinePerformanceTools.html#PerfMonCountEntities", [
          [ "Performance Counter", "OnlinePerformanceTools.html#PerfMonCountCounter", null ],
          [ "Performance Counter Type", "OnlinePerformanceTools.html#PerfMonCountCounterType", null ],
          [ "Performance Counter Scope", "OnlinePerformanceTools.html#PerfMonCountCounterScope", null ],
          [ "Performance Counter Set", "OnlinePerformanceTools.html#PerfMonCountCounterSet", null ],
          [ "Performance Counter Sample", "OnlinePerformanceTools.html#PerfMonCountCounterSample", null ],
          [ "Performance Counter Listener", "OnlinePerformanceTools.html#PerfMonCountCounterListener", null ],
          [ "Application Programming Interface", "OnlinePerformanceTools.html#PerfMonCountCounterAPI", null ]
        ] ],
        [ "Implementation Details", "OnlinePerformanceTools.html#PerfMonCountCounterImplementation", [
          [ "Performance Counter Registration", "OnlinePerformanceTools.html#PerfMonCountCounterImplRegistration", null ],
          [ "Performance Sample Updaters", "OnlinePerformanceTools.html#PerfMonCountCounterImplUpdaters", null ],
          [ "Counter operations", "OnlinePerformanceTools.html#PerfMonCountCounterImplOperations", null ],
          [ "Runtime checks", "OnlinePerformanceTools.html#PerfMonCountCounterImplRuntime", null ]
        ] ],
        [ "Exported Counters", "OnlinePerformanceTools.html#PerfMonCountCounterExported", [
          [ "Global Scope", "OnlinePerformanceTools.html#PerfMonCountCounterExportedGlobal", null ],
          [ "Per-worker Scope", "OnlinePerformanceTools.html#PerfMonCountCounterExportedPerWorker", null ],
          [ "Per-Codelet Scope", "OnlinePerformanceTools.html#PerfMonCountCounterExportedPerCodelet", null ]
        ] ],
        [ "Sequence of operations", "OnlinePerformanceTools.html#PerfMonCountCounterSequence", null ]
      ] ],
      [ "Performance Steering Knobs", "OnlinePerformanceTools.html#PerfKnobs", [
        [ "Objectives", "OnlinePerformanceTools.html#PerfKnobsObjectives", null ],
        [ "Entities", "OnlinePerformanceTools.html#PerfKnobsEntities", [
          [ "Performance Steering Knob", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnob", null ],
          [ "Knob Type", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnobType", null ],
          [ "Knob Scope", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnobScope", null ],
          [ "Knob Group", "OnlinePerformanceTools.html#PerfKnobsEntitiesKnobGroup", null ]
        ] ],
        [ "Application Programming Interface", "OnlinePerformanceTools.html#PerfKnobsAPI", null ],
        [ "Implementation Details", "OnlinePerformanceTools.html#PerfKnobsImpl", null ],
        [ "Exported Steering Knobs", "OnlinePerformanceTools.html#PerfKnobsExported", [
          [ "Global Scope", "OnlinePerformanceTools.html#PerfKnobsExportedGlobal", null ],
          [ "Per-worker Scope", "OnlinePerformanceTools.html#PerfKnobsExportedPerWorker", null ],
          [ "Per-Scheduler Scope", "OnlinePerformanceTools.html#PerfKnobsExportedPerScheduler", null ]
        ] ],
        [ "Sequence of operations", "OnlinePerformanceTools.html#PerfKnobsSequence", null ]
      ] ]
    ] ],
    [ "Offline Performance Tools", "OfflinePerformanceTools.html", [
      [ "Generating Traces With FxT", "OfflinePerformanceTools.html#GeneratingTracesWithFxT", [
        [ "Creating a Gantt Diagram", "OfflinePerformanceTools.html#CreatingAGanttDiagram", [
          [ "Zooming in Gantt Diagram", "OfflinePerformanceTools.html#ZoomingInGantt", null ],
          [ "Colors in Gantt Diagram", "OfflinePerformanceTools.html#ColorsInGantt", null ],
          [ "Curves in Gantt Diagram", "OfflinePerformanceTools.html#CurvesInGantt", null ],
          [ "States in Gantt Diagram", "OfflinePerformanceTools.html#StatesInGantt", null ],
          [ "Transfers in Gantt Diagram", "OfflinePerformanceTools.html#TransfersInGantt", null ],
          [ "Scheduler in Gantt Diagram", "OfflinePerformanceTools.html#SchedulerInGantt", null ],
          [ "Main Thread in Gantt Diagram", "OfflinePerformanceTools.html#MainThreadInGantt", null ],
          [ "Statistics in Gantt Diagram", "OfflinePerformanceTools.html#StatisticsInGantt", null ]
        ] ],
        [ "Creating a DAG With Graphviz", "OfflinePerformanceTools.html#CreatingADAGWithGraphviz", null ],
        [ "Getting Task Details", "OfflinePerformanceTools.html#TraceTaskDetails", null ],
        [ "Getting Scheduling Task Details", "OfflinePerformanceTools.html#TraceSchedTaskDetails", null ],
        [ "Monitoring Activity", "OfflinePerformanceTools.html#MonitoringActivity", null ],
        [ "Getting Modular Schedular Animation", "OfflinePerformanceTools.html#Animation", null ],
        [ "Analyzing Time Between MPI Data Transfer and Use by Tasks", "OfflinePerformanceTools.html#TimeBetweenSendRecvDataUse", null ],
        [ "Number of events in trace files", "OfflinePerformanceTools.html#NumberEvents", null ],
        [ "Limiting The Scope Of The Trace", "OfflinePerformanceTools.html#LimitingScopeTrace", null ]
      ] ],
      [ "Performance Of Codelets", "OfflinePerformanceTools.html#PerformanceOfCodelets", null ],
      [ "Energy Of Codelets", "OfflinePerformanceTools.html#EnergyOfCodelets", null ],
      [ "Data trace and tasks length", "OfflinePerformanceTools.html#DataTrace", null ],
      [ "Trace Statistics", "OfflinePerformanceTools.html#TraceStatistics", null ],
      [ "PAPI counters", "OfflinePerformanceTools.html#PapiCounters", null ],
      [ "Theoretical Lower Bound On Execution Time", "OfflinePerformanceTools.html#TheoreticalLowerBoundOnExecutionTime", null ],
      [ "Trace visualization with StarVZ", "OfflinePerformanceTools.html#starvz", null ],
      [ "StarPU Eclipse Plugin", "OfflinePerformanceTools.html#EclipsePlugin", [
        [ "Eclipse Installation", "OfflinePerformanceTools.html#EclipseInstallation", null ],
        [ "StarPU Eclipse Plugin Compilation and Installation", "OfflinePerformanceTools.html#PluginInstallation", null ],
        [ "StarPU Eclipse Plugin Instruction", "OfflinePerformanceTools.html#PluginInstruction", null ]
      ] ],
      [ "Memory Feedback", "OfflinePerformanceTools.html#MemoryFeedback", null ],
      [ "Data Statistics", "OfflinePerformanceTools.html#DataStatistics", null ],
      [ "Tracing MPI applications", "OfflinePerformanceTools.html#TraceMpi", null ],
      [ "Verbose Traces", "OfflinePerformanceTools.html#VerboseTraces", null ]
    ] ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"BenchmarkingStarPU.html",
"group__API__Codelet__And__Tasks.html#a593418a8961318e4085177abeeaa43ad",
"group__API__Data__Interfaces.html#a99f4a2889d2184c091620140fa517e37",
"group__API__Data__Interfaces.html#gadcf7063b1cd8d0feed7054e6e4d9d217",
"group__API__Explicit__Dependencies.html#gaccd7b337e14269be734af274fb11c1a4",
"group__API__Interop__Support.html#ga94cde8773f6f1a01e96812471336266d",
"group__API__Modularized__Scheduler.html#ga782b27a1b864b0d21294f3d8da8756f8",
"group__API__Parallel__Worker.html#ga186aa3508b97b85ec96a6bafe2b2d590",
"group__API__Profiling.html#a8f4291afbbd7fcf885a3d30a72f2dd78",
"group__API__Scheduling__Policy.html#a0e378575c3d948a10e1025dd817bba67",
"group__API__Workers.html#ga1552f16bc4b25d839efc732180efa130",
"interfacefstarpu__mod_1_1fstarpu__data__get__sub__data.html",
"interfacefstarpu__mod_1_1fstarpu__sched__ctx__remove__workers.html",
"interfacefstarpu__mpi__mod_1_1fstarpu__mpi__task__insert.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
